==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/m365securityandcompliance/kotlin/inputs/ServicesResourceIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.m365securityandcompliance.kotlin.inputs

import com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs.builder
import com.pulumi.azurenative.m365securityandcompliance.kotlin.enums.ManagedServiceIdentityType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Setting indicating whether the service has a managed identity associated with it.
 * @property type Type of identity being specified, currently SystemAssigned and None are allowed.
 */
public data class ServicesResourceIdentityArgs(
    public val type: Output<Either<String, ManagedServiceIdentityType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs> {
    override fun toJava():
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs =
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs.builder()
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ServicesResourceIdentityArgs].
 */
@PulumiTagMarker
public class ServicesResourceIdentityArgsBuilder internal constructor() {
    private var type: Output<Either<String, ManagedServiceIdentityType>>? = null

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("bamtibljnsbfayje")
    public suspend fun type(`value`: Output<Either<String, ManagedServiceIdentityType>>) {
        this.type = value
    }

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("delvomiwstiloylx")
    public suspend fun type(`value`: Either<String, ManagedServiceIdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("dmbfwrpspovivcuh")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedServiceIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("spxpvmxteoamnqem")
    public fun type(`value`: ManagedServiceIdentityType) {
        val toBeMapped = Either.ofRight<String, ManagedServiceIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ServicesResourceIdentityArgs = ServicesResourceIdentityArgs(
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/m365securityandcompliance/kotlin/inputs/ServicesResourceIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.m365securityandcompliance.kotlin.inputs

import com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs.builder
import com.pulumi.azurenative.m365securityandcompliance.kotlin.enums.ManagedServiceIdentityType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Setting indicating whether the service has a managed identity associated with it.
 * @property type Type of identity being specified, currently SystemAssigned and None are allowed.
 */
public data class ServicesResourceIdentityArgs(
    public val type: Output<Either<String, ManagedServiceIdentityType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs> {
    override fun toJava():
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs =
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServicesResourceIdentityArgs.builder()
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ServicesResourceIdentityArgs].
 */
@PulumiTagMarker
public class ServicesResourceIdentityArgsBuilder internal constructor() {
    private var type: Output<Either<String, ManagedServiceIdentityType>>? = null

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("ylnjaifvovlgelhp")
    public suspend fun type(`value`: Output<Either<String, ManagedServiceIdentityType>>) {
        this.type = value
    }

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("esxnqommrxexmsbs")
    public suspend fun type(`value`: Either<String, ManagedServiceIdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("cgudkjpesqeerbfg")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedServiceIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of identity being specified, currently SystemAssigned and None are allowed.
     */
    @JvmName("ntgvckxqixxkkttk")
    public fun type(`value`: ManagedServiceIdentityType) {
        val toBeMapped = Either.ofRight<String, ManagedServiceIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ServicesResourceIdentityArgs = ServicesResourceIdentityArgs(
        type = type,
    )
}
